@@ -59,6 +59,7 @@ class Zruchnaio extends \FreePBX_Helpers implements \BMO
             'freepbx_module_secret' => $this->createSecret(),
             'freepbx_base_uri' => '',
             'records_extension' => 'wav',
+            'freepbx_callback_extension' => '',
             'client_name' => '',
         ]);
 
@@ -244,7 +245,7 @@ class Zruchnaio extends \FreePBX_Helpers implements \BMO
         $ext->add($section, $extension, '', new \ext_set('ODBC_NEWCDRIN(${startcdrnew},${clientnum},,${FROM_DID},${NODEST},NO ANSWER,${CHANNEL(LINKEDID)},${CHANNEL(accountcode)},${CDR(duration)},${timecall},${CALLFILENAME}.mp3)'));
         $ext->add($section, $extension, '', new \ext_noop('${DB(${FROM_DID}/${CALLERID(num)}/num)}'));
         $ext->add($section, $extension, '', new \ext_noop('${DB(${FROM_DID}/${CALLERID(num)}/account)}'));
-        $ext->add($section, $extension, '', new \ext_gosub('1', 's', 'misscalldbdel'));
+        $ext->add($section, $extension, 'dbdel', new \ext_gosub('1', 's', 'misscalldbdel'));
         $ext->add($section, $extension, '', new \ext_set('CDR(userfield)', 'miss_call'));
         $ext->add($section, $extension, '', new \ext_return());
     }
@@ -316,7 +317,7 @@ class Zruchnaio extends \FreePBX_Helpers implements \BMO
         $ext->add($section, $extension, '', new \ext_dbget('CallStart', '${FROM_DID}/${CALLERID(num)}/num/callstart'));
         $ext->add($section, $extension, '', new \ext_set('CallStop', '${STRFTIME(epoch,,%s)}'));
         $ext->add($section, $extension, '', new \ext_set('timecall', '${MATH(${CallStop}-${CallStart},int)}'));
-        $ext->add($section, $extension, '', new \ext_execif('$["${innumber}" != ""]', 'System', $this->getBinFileExec('hangup', array('klient' => $this->getClientName())).' "${CALLERID(num)}" "${FROM_DID}" "${DB(${FROM_DID}/${CALLERID(num)}/num)}" "${timecall}" "ANSWERED" "/var/spool/asterisk/monitor/${YEAR}/${MONTH}/${DAY}/${CALLFILENAME}.mp3" "${CHANNEL(LINKEDID)}" "${DB(${FROM_DID}/${CALLERID(num)}/account)}" &'));
+        $ext->add($section, $extension, 'send', new \ext_execif('$["${innumber}" != ""]', 'System', $this->getBinFileExec('hangup', array('klient' => $this->getClientName())).' "${CALLERID(num)}" "${FROM_DID}" "${DB(${FROM_DID}/${CALLERID(num)}/num)}" "${timecall}" "ANSWERED" "/var/spool/asterisk/monitor/${YEAR}/${MONTH}/${DAY}/${CALLFILENAME}.mp3" "${CHANNEL(LINKEDID)}" "${DB(${FROM_DID}/${CALLERID(num)}/account)}" &'));
         $ext->add($section, $extension, '', new \ext_gosubif('$[${innumber}" != ""]', 'in-call-end-dbdel,s,1'));
         $ext->add($section, $extension, '', new \ext_noop());
         $ext->add($section, $extension, '', new \ext_return());
@@ -581,6 +582,7 @@ class Zruchnaio extends \FreePBX_Helpers implements \BMO
                         return load_view(__DIR__ . '/views/setup.php', [
                             'freepbxBaseUrl' => $this->getConfig('freepbx_base_uri'),
                             'recordsExtension' => $this->getConfig('records_extension'),
+                            'freepbxCallbackExtension' => $this->getConfig('freepbx_callback_extension'),
                             'clientName' => $this->getClientName(),
                             'error' => isset($_GET['error']) ? $_GET['error'] : '',
                         ]);
@@ -594,8 +596,9 @@ class Zruchnaio extends \FreePBX_Helpers implements \BMO
                         );
 
                         if (!empty($_REQUEST['bx24_application_secret'])) {
-                            if ($this->touchIntegrationConfigs($_REQUEST['bx24_application_secret'], $_REQUEST['freepbx_base_uri'])) {
+                            if ($this->touchIntegrationConfigs($_REQUEST['bx24_application_secret'], $_REQUEST['freepbx_base_uri'], $_REQUEST['freepbx_callback_extension'])) {
                                 $this->setConfig('freepbx_base_uri', $_REQUEST['freepbx_base_uri']);
+                                $this->setConfig('freepbx_callback_extension', $_REQUEST['freepbx_callback_extension']);
                             } else {
                                 $_SERVER['REQUEST_URI'] .= false !== strpos($_SERVER['REQUEST_URI'], '?') ? '&' : '?';
                                 $_SERVER['REQUEST_URI'] .= 'error=failed-public-url';
@@ -616,12 +619,13 @@ class Zruchnaio extends \FreePBX_Helpers implements \BMO
     /**
      * @param string $bx24Secret
      * @param string $freepbxBaseUri
+     * @param string $freepbxCallbackExtension
      * @throws \RuntimeException
      * @return bool
      *
      * @api
      */
-    private function touchIntegrationConfigs($bx24Secret, $freepbxBaseUri)
+    private function touchIntegrationConfigs($bx24Secret, $freepbxBaseUri, $freepbxCallbackExtension)
     {
         $ch = curl_init('https://asterisk-connect.zruchna.io/freepbx/api/v1/registration');
         curl_setopt_array($ch, [
@@ -637,6 +641,7 @@ class Zruchnaio extends \FreePBX_Helpers implements \BMO
                     'freepbx_module_secret' => $this->getSecretValue(),
                     'bitrix24_app_secret' => $bx24Secret,
                     'freepbx_base_uri' => $freepbxBaseUri,
+                    'freepbx_callback_extension' => $freepbxCallbackExtension,
                 ],
             ], '', '&', PHP_QUERY_RFC3986),
         ]);
